package Locale::CLDR::Af::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 10:09:19 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Af');

no Moose;
__PACKAGE__->meta->make_immutable;
